pub struct VirtualsPool {
pub creator: Pubkey,
pub mint: Pubkey,
pub virtual_y: u64,
pub graduation_x: u64,
pub state: PoolState,
pub bump: u8,
}Fields
creator: Pubkeymint: Pubkeyvirtual_y: u64graduation_x: u64state: PoolStatebump: u8Trait Implementations
Sourceimpl BorshDeserialize for VirtualsPoolwhere
Pubkey: BorshDeserialize,
u64: BorshDeserialize,
PoolState: BorshDeserialize,
u8: BorshDeserialize,
impl BorshDeserialize for VirtualsPoolwhere
Pubkey: BorshDeserialize,
u64: BorshDeserialize,
PoolState: BorshDeserialize,
u8: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl CarbonDeserialize for VirtualsPool
impl CarbonDeserialize for VirtualsPool
const DISCRIMINATOR: &'static [u8]
fn deserialize(data: &[u8]) -> Option<Self>
Sourceimpl Clone for VirtualsPool
impl Clone for VirtualsPool
Sourcefn clone(&self) -> VirtualsPool
fn clone(&self) -> VirtualsPool
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VirtualsPool
impl Debug for VirtualsPool
Sourceimpl<'de> Deserialize<'de> for VirtualsPool
impl<'de> Deserialize<'de> for VirtualsPool
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for VirtualsPool
impl Hash for VirtualsPool
Sourceimpl PartialEq for VirtualsPool
impl PartialEq for VirtualsPool
Sourceimpl Serialize for VirtualsPool
impl Serialize for VirtualsPool
impl Eq for VirtualsPool
impl StructuralPartialEq for VirtualsPool