pub struct CreateMeteoraPool {}Trait Implementations
Sourceimpl ArrangeAccounts for CreateMeteoraPool
impl ArrangeAccounts for CreateMeteoraPool
type ArrangedAccounts = CreateMeteoraPoolInstructionAccounts
fn arrange_accounts(accounts: &[AccountMeta]) -> Option<Self::ArrangedAccounts>
Sourceimpl BorshDeserialize for CreateMeteoraPool
impl BorshDeserialize for CreateMeteoraPool
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl CarbonDeserialize for CreateMeteoraPool
impl CarbonDeserialize for CreateMeteoraPool
const DISCRIMINATOR: &'static [u8]
fn deserialize(data: &[u8]) -> Option<Self>
Sourceimpl Clone for CreateMeteoraPool
impl Clone for CreateMeteoraPool
Sourcefn clone(&self) -> CreateMeteoraPool
fn clone(&self) -> CreateMeteoraPool
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CreateMeteoraPool
impl Debug for CreateMeteoraPool
Sourceimpl<'de> Deserialize<'de> for CreateMeteoraPool
impl<'de> Deserialize<'de> for CreateMeteoraPool
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for CreateMeteoraPool
impl Hash for CreateMeteoraPool
Sourceimpl PartialEq for CreateMeteoraPool
impl PartialEq for CreateMeteoraPool
Sourceimpl Serialize for CreateMeteoraPool
impl Serialize for CreateMeteoraPool
impl Eq for CreateMeteoraPool
impl StructuralPartialEq for CreateMeteoraPool