pub struct GraduationEvent {
pub vpool: Pubkey,
pub mint: Pubkey,
pub balance: u64,
}Fields
vpool: Pubkeymint: Pubkeybalance: u64Trait Implementations
Sourceimpl BorshDeserialize for GraduationEvent
impl BorshDeserialize for GraduationEvent
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl CarbonDeserialize for GraduationEvent
impl CarbonDeserialize for GraduationEvent
const DISCRIMINATOR: &'static [u8]
fn deserialize(data: &[u8]) -> Option<Self>
Sourceimpl Clone for GraduationEvent
impl Clone for GraduationEvent
Sourcefn clone(&self) -> GraduationEvent
fn clone(&self) -> GraduationEvent
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GraduationEvent
impl Debug for GraduationEvent
Sourceimpl<'de> Deserialize<'de> for GraduationEvent
impl<'de> Deserialize<'de> for GraduationEvent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for GraduationEvent
impl Hash for GraduationEvent
Sourceimpl PartialEq for GraduationEvent
impl PartialEq for GraduationEvent
Sourceimpl Serialize for GraduationEvent
impl Serialize for GraduationEvent
impl Eq for GraduationEvent
impl StructuralPartialEq for GraduationEvent