pub struct Launch {
pub symbol: String,
pub name: String,
pub uri: String,
}Fields
symbol: Stringname: Stringuri: StringTrait Implementations
Sourceimpl ArrangeAccounts for Launch
impl ArrangeAccounts for Launch
type ArrangedAccounts = LaunchInstructionAccounts
fn arrange_accounts(accounts: &[AccountMeta]) -> Option<Self::ArrangedAccounts>
Sourceimpl BorshDeserialize for Launchwhere
String: BorshDeserialize,
impl BorshDeserialize for Launchwhere
String: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl CarbonDeserialize for Launch
impl CarbonDeserialize for Launch
const DISCRIMINATOR: &'static [u8]
fn deserialize(data: &[u8]) -> Option<Self>
Sourceimpl<'de> Deserialize<'de> for Launch
impl<'de> Deserialize<'de> for Launch
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for Launch
impl StructuralPartialEq for Launch