pub struct LaunchEvent {
pub vpool: Pubkey,
pub mint: Pubkey,
pub creator: Pubkey,
}Fields
vpool: Pubkeymint: Pubkeycreator: PubkeyTrait Implementations
Sourceimpl BorshDeserialize for LaunchEventwhere
Pubkey: BorshDeserialize,
impl BorshDeserialize for LaunchEventwhere
Pubkey: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl CarbonDeserialize for LaunchEvent
impl CarbonDeserialize for LaunchEvent
const DISCRIMINATOR: &'static [u8]
fn deserialize(data: &[u8]) -> Option<Self>
Sourceimpl Clone for LaunchEvent
impl Clone for LaunchEvent
Sourcefn clone(&self) -> LaunchEvent
fn clone(&self) -> LaunchEvent
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LaunchEvent
impl Debug for LaunchEvent
Sourceimpl<'de> Deserialize<'de> for LaunchEvent
impl<'de> Deserialize<'de> for LaunchEvent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for LaunchEvent
impl Hash for LaunchEvent
Sourceimpl PartialEq for LaunchEvent
impl PartialEq for LaunchEvent
Sourceimpl Serialize for LaunchEvent
impl Serialize for LaunchEvent
impl Eq for LaunchEvent
impl StructuralPartialEq for LaunchEvent