pub struct UpdatePoolCreator {}Trait Implementations
Sourceimpl ArrangeAccounts for UpdatePoolCreator
impl ArrangeAccounts for UpdatePoolCreator
type ArrangedAccounts = UpdatePoolCreatorInstructionAccounts
fn arrange_accounts(accounts: &[AccountMeta]) -> Option<Self::ArrangedAccounts>
Sourceimpl BorshDeserialize for UpdatePoolCreator
impl BorshDeserialize for UpdatePoolCreator
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl CarbonDeserialize for UpdatePoolCreator
impl CarbonDeserialize for UpdatePoolCreator
const DISCRIMINATOR: &'static [u8]
fn deserialize(data: &[u8]) -> Option<Self>
Sourceimpl Clone for UpdatePoolCreator
impl Clone for UpdatePoolCreator
Sourcefn clone(&self) -> UpdatePoolCreator
fn clone(&self) -> UpdatePoolCreator
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UpdatePoolCreator
impl Debug for UpdatePoolCreator
Sourceimpl<'de> Deserialize<'de> for UpdatePoolCreator
impl<'de> Deserialize<'de> for UpdatePoolCreator
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for UpdatePoolCreator
impl Hash for UpdatePoolCreator
Sourceimpl PartialEq for UpdatePoolCreator
impl PartialEq for UpdatePoolCreator
Sourceimpl Serialize for UpdatePoolCreator
impl Serialize for UpdatePoolCreator
impl Eq for UpdatePoolCreator
impl StructuralPartialEq for UpdatePoolCreator